- You can follow along with the video using this notebook: Deep Features for Image Retrieval.ipynb
- Download the wikipedia dataset with training images here: image_train_data.zip
- Download the wikipedia dataset with test images here: image_test_data.zip
- Save all of these files in the same directory (where you are calling iPython notebook from) and unzip the data files.
- Open the notebook using IPython Notebook.
- Note that this is the same notebook used in the programming assignment for this module.